import {
  AutomaticJsonStringConversion as __AutomaticJsonStringConversion,
  ExceptionOptionType as __ExceptionOptionType,
} from "@smithy/smithy-client";
import { TextractServiceException as __BaseException } from "./TextractServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export interface Adapter {
  AdapterId: string | undefined;
  Pages?: string[] | undefined;
  Version: string | undefined;
}
export declare const FeatureType: {
  readonly FORMS: "FORMS";
  readonly LAYOUT: "LAYOUT";
  readonly QUERIES: "QUERIES";
  readonly SIGNATURES: "SIGNATURES";
  readonly TABLES: "TABLES";
};
export type FeatureType = (typeof FeatureType)[keyof typeof FeatureType];
export interface AdapterOverview {
  AdapterId?: string | undefined;
  AdapterName?: string | undefined;
  CreationTime?: Date | undefined;
  FeatureTypes?: FeatureType[] | undefined;
}
export interface AdaptersConfig {
  Adapters: Adapter[] | undefined;
}
export interface S3Object {
  Bucket?: string | undefined;
  Name?: string | undefined;
  Version?: string | undefined;
}
export interface AdapterVersionDatasetConfig {
  ManifestS3Object?: S3Object | undefined;
}
export interface EvaluationMetric {
  F1Score?: number | undefined;
  Precision?: number | undefined;
  Recall?: number | undefined;
}
export interface AdapterVersionEvaluationMetric {
  Baseline?: EvaluationMetric | undefined;
  AdapterVersion?: EvaluationMetric | undefined;
  FeatureType?: FeatureType | undefined;
}
export declare const AdapterVersionStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly AT_RISK: "AT_RISK";
  readonly CREATION_ERROR: "CREATION_ERROR";
  readonly CREATION_IN_PROGRESS: "CREATION_IN_PROGRESS";
  readonly DEPRECATED: "DEPRECATED";
};
export type AdapterVersionStatus =
  (typeof AdapterVersionStatus)[keyof typeof AdapterVersionStatus];
export interface AdapterVersionOverview {
  AdapterId?: string | undefined;
  AdapterVersion?: string | undefined;
  CreationTime?: Date | undefined;
  FeatureTypes?: FeatureType[] | undefined;
  Status?: AdapterVersionStatus | undefined;
  StatusMessage?: string | undefined;
}
export interface Document {
  Bytes?: Uint8Array | undefined;
  S3Object?: S3Object | undefined;
}
export declare const ContentClassifier: {
  readonly FREE_OF_ADULT_CONTENT: "FreeOfAdultContent";
  readonly FREE_OF_PERSONALLY_IDENTIFIABLE_INFORMATION: "FreeOfPersonallyIdentifiableInformation";
};
export type ContentClassifier =
  (typeof ContentClassifier)[keyof typeof ContentClassifier];
export interface HumanLoopDataAttributes {
  ContentClassifiers?: ContentClassifier[] | undefined;
}
export interface HumanLoopConfig {
  HumanLoopName: string | undefined;
  FlowDefinitionArn: string | undefined;
  DataAttributes?: HumanLoopDataAttributes | undefined;
}
export interface Query {
  Text: string | undefined;
  Alias?: string | undefined;
  Pages?: string[] | undefined;
}
export interface QueriesConfig {
  Queries: Query[] | undefined;
}
export interface AnalyzeDocumentRequest {
  Document: Document | undefined;
  FeatureTypes: FeatureType[] | undefined;
  HumanLoopConfig?: HumanLoopConfig | undefined;
  QueriesConfig?: QueriesConfig | undefined;
  AdaptersConfig?: AdaptersConfig | undefined;
}
export declare const BlockType: {
  readonly CELL: "CELL";
  readonly KEY_VALUE_SET: "KEY_VALUE_SET";
  readonly LAYOUT_FIGURE: "LAYOUT_FIGURE";
  readonly LAYOUT_FOOTER: "LAYOUT_FOOTER";
  readonly LAYOUT_HEADER: "LAYOUT_HEADER";
  readonly LAYOUT_KEY_VALUE: "LAYOUT_KEY_VALUE";
  readonly LAYOUT_LIST: "LAYOUT_LIST";
  readonly LAYOUT_PAGE_NUMBER: "LAYOUT_PAGE_NUMBER";
  readonly LAYOUT_SECTION_HEADER: "LAYOUT_SECTION_HEADER";
  readonly LAYOUT_TABLE: "LAYOUT_TABLE";
  readonly LAYOUT_TEXT: "LAYOUT_TEXT";
  readonly LAYOUT_TITLE: "LAYOUT_TITLE";
  readonly LINE: "LINE";
  readonly MERGED_CELL: "MERGED_CELL";
  readonly PAGE: "PAGE";
  readonly QUERY: "QUERY";
  readonly QUERY_RESULT: "QUERY_RESULT";
  readonly SELECTION_ELEMENT: "SELECTION_ELEMENT";
  readonly SIGNATURE: "SIGNATURE";
  readonly TABLE: "TABLE";
  readonly TABLE_FOOTER: "TABLE_FOOTER";
  readonly TABLE_TITLE: "TABLE_TITLE";
  readonly TITLE: "TITLE";
  readonly WORD: "WORD";
};
export type BlockType = (typeof BlockType)[keyof typeof BlockType];
export declare const EntityType: {
  readonly COLUMN_HEADER: "COLUMN_HEADER";
  readonly KEY: "KEY";
  readonly SEMI_STRUCTURED_TABLE: "SEMI_STRUCTURED_TABLE";
  readonly STRUCTURED_TABLE: "STRUCTURED_TABLE";
  readonly TABLE_FOOTER: "TABLE_FOOTER";
  readonly TABLE_SECTION_TITLE: "TABLE_SECTION_TITLE";
  readonly TABLE_SUMMARY: "TABLE_SUMMARY";
  readonly TABLE_TITLE: "TABLE_TITLE";
  readonly VALUE: "VALUE";
};
export type EntityType = (typeof EntityType)[keyof typeof EntityType];
export interface BoundingBox {
  Width?: number | undefined;
  Height?: number | undefined;
  Left?: number | undefined;
  Top?: number | undefined;
}
export interface Point {
  X?: number | undefined;
  Y?: number | undefined;
}
export interface Geometry {
  BoundingBox?: BoundingBox | undefined;
  Polygon?: Point[] | undefined;
}
export declare const RelationshipType: {
  readonly ANSWER: "ANSWER";
  readonly CHILD: "CHILD";
  readonly COMPLEX_FEATURES: "COMPLEX_FEATURES";
  readonly MERGED_CELL: "MERGED_CELL";
  readonly TABLE: "TABLE";
  readonly TABLE_FOOTER: "TABLE_FOOTER";
  readonly TABLE_TITLE: "TABLE_TITLE";
  readonly TITLE: "TITLE";
  readonly VALUE: "VALUE";
};
export type RelationshipType =
  (typeof RelationshipType)[keyof typeof RelationshipType];
export interface Relationship {
  Type?: RelationshipType | undefined;
  Ids?: string[] | undefined;
}
export declare const SelectionStatus: {
  readonly NOT_SELECTED: "NOT_SELECTED";
  readonly SELECTED: "SELECTED";
};
export type SelectionStatus =
  (typeof SelectionStatus)[keyof typeof SelectionStatus];
export declare const TextType: {
  readonly HANDWRITING: "HANDWRITING";
  readonly PRINTED: "PRINTED";
};
export type TextType = (typeof TextType)[keyof typeof TextType];
export interface Block {
  BlockType?: BlockType | undefined;
  Confidence?: number | undefined;
  Text?: string | undefined;
  TextType?: TextType | undefined;
  RowIndex?: number | undefined;
  ColumnIndex?: number | undefined;
  RowSpan?: number | undefined;
  ColumnSpan?: number | undefined;
  Geometry?: Geometry | undefined;
  Id?: string | undefined;
  Relationships?: Relationship[] | undefined;
  EntityTypes?: EntityType[] | undefined;
  SelectionStatus?: SelectionStatus | undefined;
  Page?: number | undefined;
  Query?: Query | undefined;
}
export interface DocumentMetadata {
  Pages?: number | undefined;
}
export interface HumanLoopActivationOutput {
  HumanLoopArn?: string | undefined;
  HumanLoopActivationReasons?: string[] | undefined;
  HumanLoopActivationConditionsEvaluationResults?:
    | __AutomaticJsonStringConversion
    | string
    | undefined;
}
export interface AnalyzeDocumentResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  Blocks?: Block[] | undefined;
  HumanLoopActivationOutput?: HumanLoopActivationOutput | undefined;
  AnalyzeDocumentModelVersion?: string | undefined;
}
export declare class BadDocumentException extends __BaseException {
  readonly name: "BadDocumentException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<BadDocumentException, __BaseException>
  );
}
export declare class DocumentTooLargeException extends __BaseException {
  readonly name: "DocumentTooLargeException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DocumentTooLargeException, __BaseException>
  );
}
export declare class HumanLoopQuotaExceededException extends __BaseException {
  readonly name: "HumanLoopQuotaExceededException";
  readonly $fault: "client";
  ResourceType?: string | undefined;
  QuotaCode?: string | undefined;
  ServiceCode?: string | undefined;
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      HumanLoopQuotaExceededException,
      __BaseException
    >
  );
}
export declare class InternalServerError extends __BaseException {
  readonly name: "InternalServerError";
  readonly $fault: "server";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InternalServerError, __BaseException>
  );
}
export declare class InvalidParameterException extends __BaseException {
  readonly name: "InvalidParameterException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidParameterException, __BaseException>
  );
}
export declare class InvalidS3ObjectException extends __BaseException {
  readonly name: "InvalidS3ObjectException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidS3ObjectException, __BaseException>
  );
}
export declare class ProvisionedThroughputExceededException extends __BaseException {
  readonly name: "ProvisionedThroughputExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      ProvisionedThroughputExceededException,
      __BaseException
    >
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "server";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export declare class UnsupportedDocumentException extends __BaseException {
  readonly name: "UnsupportedDocumentException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<UnsupportedDocumentException, __BaseException>
  );
}
export interface AnalyzeExpenseRequest {
  Document: Document | undefined;
}
export interface ExpenseCurrency {
  Code?: string | undefined;
  Confidence?: number | undefined;
}
export interface ExpenseGroupProperty {
  Types?: string[] | undefined;
  Id?: string | undefined;
}
export interface ExpenseDetection {
  Text?: string | undefined;
  Geometry?: Geometry | undefined;
  Confidence?: number | undefined;
}
export interface ExpenseType {
  Text?: string | undefined;
  Confidence?: number | undefined;
}
export interface ExpenseField {
  Type?: ExpenseType | undefined;
  LabelDetection?: ExpenseDetection | undefined;
  ValueDetection?: ExpenseDetection | undefined;
  PageNumber?: number | undefined;
  Currency?: ExpenseCurrency | undefined;
  GroupProperties?: ExpenseGroupProperty[] | undefined;
}
export interface LineItemFields {
  LineItemExpenseFields?: ExpenseField[] | undefined;
}
export interface LineItemGroup {
  LineItemGroupIndex?: number | undefined;
  LineItems?: LineItemFields[] | undefined;
}
export interface ExpenseDocument {
  ExpenseIndex?: number | undefined;
  SummaryFields?: ExpenseField[] | undefined;
  LineItemGroups?: LineItemGroup[] | undefined;
  Blocks?: Block[] | undefined;
}
export interface AnalyzeExpenseResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  ExpenseDocuments?: ExpenseDocument[] | undefined;
}
export interface AnalyzeIDRequest {
  DocumentPages: Document[] | undefined;
}
export declare const ValueType: {
  readonly DATE: "DATE";
};
export type ValueType = (typeof ValueType)[keyof typeof ValueType];
export interface NormalizedValue {
  Value?: string | undefined;
  ValueType?: ValueType | undefined;
}
export interface AnalyzeIDDetections {
  Text: string | undefined;
  NormalizedValue?: NormalizedValue | undefined;
  Confidence?: number | undefined;
}
export interface IdentityDocumentField {
  Type?: AnalyzeIDDetections | undefined;
  ValueDetection?: AnalyzeIDDetections | undefined;
}
export interface IdentityDocument {
  DocumentIndex?: number | undefined;
  IdentityDocumentFields?: IdentityDocumentField[] | undefined;
  Blocks?: Block[] | undefined;
}
export interface AnalyzeIDResponse {
  IdentityDocuments?: IdentityDocument[] | undefined;
  DocumentMetadata?: DocumentMetadata | undefined;
  AnalyzeIDModelVersion?: string | undefined;
}
export declare const AutoUpdate: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type AutoUpdate = (typeof AutoUpdate)[keyof typeof AutoUpdate];
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface CreateAdapterRequest {
  AdapterName: string | undefined;
  ClientRequestToken?: string | undefined;
  Description?: string | undefined;
  FeatureTypes: FeatureType[] | undefined;
  AutoUpdate?: AutoUpdate | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateAdapterResponse {
  AdapterId?: string | undefined;
}
export declare class IdempotentParameterMismatchException extends __BaseException {
  readonly name: "IdempotentParameterMismatchException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      IdempotentParameterMismatchException,
      __BaseException
    >
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface OutputConfig {
  S3Bucket: string | undefined;
  S3Prefix?: string | undefined;
}
export interface CreateAdapterVersionRequest {
  AdapterId: string | undefined;
  ClientRequestToken?: string | undefined;
  DatasetConfig: AdapterVersionDatasetConfig | undefined;
  KMSKeyId?: string | undefined;
  OutputConfig: OutputConfig | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateAdapterVersionResponse {
  AdapterId?: string | undefined;
  AdapterVersion?: string | undefined;
}
export declare class InvalidKMSKeyException extends __BaseException {
  readonly name: "InvalidKMSKeyException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidKMSKeyException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface DeleteAdapterRequest {
  AdapterId: string | undefined;
}
export interface DeleteAdapterResponse {}
export interface DeleteAdapterVersionRequest {
  AdapterId: string | undefined;
  AdapterVersion: string | undefined;
}
export interface DeleteAdapterVersionResponse {}
export interface DetectDocumentTextRequest {
  Document: Document | undefined;
}
export interface DetectDocumentTextResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  Blocks?: Block[] | undefined;
  DetectDocumentTextModelVersion?: string | undefined;
}
export interface DetectedSignature {
  Page?: number | undefined;
}
export interface SplitDocument {
  Index?: number | undefined;
  Pages?: number[] | undefined;
}
export interface UndetectedSignature {
  Page?: number | undefined;
}
export interface DocumentGroup {
  Type?: string | undefined;
  SplitDocuments?: SplitDocument[] | undefined;
  DetectedSignatures?: DetectedSignature[] | undefined;
  UndetectedSignatures?: UndetectedSignature[] | undefined;
}
export interface DocumentLocation {
  S3Object?: S3Object | undefined;
}
export interface LendingDetection {
  Text?: string | undefined;
  SelectionStatus?: SelectionStatus | undefined;
  Geometry?: Geometry | undefined;
  Confidence?: number | undefined;
}
export interface LendingField {
  Type?: string | undefined;
  KeyDetection?: LendingDetection | undefined;
  ValueDetections?: LendingDetection[] | undefined;
}
export interface SignatureDetection {
  Confidence?: number | undefined;
  Geometry?: Geometry | undefined;
}
export interface LendingDocument {
  LendingFields?: LendingField[] | undefined;
  SignatureDetections?: SignatureDetection[] | undefined;
}
export interface Extraction {
  LendingDocument?: LendingDocument | undefined;
  ExpenseDocument?: ExpenseDocument | undefined;
  IdentityDocument?: IdentityDocument | undefined;
}
export interface GetAdapterRequest {
  AdapterId: string | undefined;
}
export interface GetAdapterResponse {
  AdapterId?: string | undefined;
  AdapterName?: string | undefined;
  CreationTime?: Date | undefined;
  Description?: string | undefined;
  FeatureTypes?: FeatureType[] | undefined;
  AutoUpdate?: AutoUpdate | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface GetAdapterVersionRequest {
  AdapterId: string | undefined;
  AdapterVersion: string | undefined;
}
export interface GetAdapterVersionResponse {
  AdapterId?: string | undefined;
  AdapterVersion?: string | undefined;
  CreationTime?: Date | undefined;
  FeatureTypes?: FeatureType[] | undefined;
  Status?: AdapterVersionStatus | undefined;
  StatusMessage?: string | undefined;
  DatasetConfig?: AdapterVersionDatasetConfig | undefined;
  KMSKeyId?: string | undefined;
  OutputConfig?: OutputConfig | undefined;
  EvaluationMetrics?: AdapterVersionEvaluationMetric[] | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface GetDocumentAnalysisRequest {
  JobId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export declare const JobStatus: {
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly PARTIAL_SUCCESS: "PARTIAL_SUCCESS";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type JobStatus = (typeof JobStatus)[keyof typeof JobStatus];
export interface Warning {
  ErrorCode?: string | undefined;
  Pages?: number[] | undefined;
}
export interface GetDocumentAnalysisResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  JobStatus?: JobStatus | undefined;
  NextToken?: string | undefined;
  Blocks?: Block[] | undefined;
  Warnings?: Warning[] | undefined;
  StatusMessage?: string | undefined;
  AnalyzeDocumentModelVersion?: string | undefined;
}
export declare class InvalidJobIdException extends __BaseException {
  readonly name: "InvalidJobIdException";
  readonly $fault: "client";
  Message?: string | undefined;
  Code?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidJobIdException, __BaseException>
  );
}
export interface GetDocumentTextDetectionRequest {
  JobId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface GetDocumentTextDetectionResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  JobStatus?: JobStatus | undefined;
  NextToken?: string | undefined;
  Blocks?: Block[] | undefined;
  Warnings?: Warning[] | undefined;
  StatusMessage?: string | undefined;
  DetectDocumentTextModelVersion?: string | undefined;
}
export interface GetExpenseAnalysisRequest {
  JobId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface GetExpenseAnalysisResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  JobStatus?: JobStatus | undefined;
  NextToken?: string | undefined;
  ExpenseDocuments?: ExpenseDocument[] | undefined;
  Warnings?: Warning[] | undefined;
  StatusMessage?: string | undefined;
  AnalyzeExpenseModelVersion?: string | undefined;
}
export interface GetLendingAnalysisRequest {
  JobId: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface Prediction {
  Value?: string | undefined;
  Confidence?: number | undefined;
}
export interface PageClassification {
  PageType: Prediction[] | undefined;
  PageNumber: Prediction[] | undefined;
}
export interface LendingResult {
  Page?: number | undefined;
  PageClassification?: PageClassification | undefined;
  Extractions?: Extraction[] | undefined;
}
export interface GetLendingAnalysisResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  JobStatus?: JobStatus | undefined;
  NextToken?: string | undefined;
  Results?: LendingResult[] | undefined;
  Warnings?: Warning[] | undefined;
  StatusMessage?: string | undefined;
  AnalyzeLendingModelVersion?: string | undefined;
}
export interface GetLendingAnalysisSummaryRequest {
  JobId: string | undefined;
}
export interface LendingSummary {
  DocumentGroups?: DocumentGroup[] | undefined;
  UndetectedDocumentTypes?: string[] | undefined;
}
export interface GetLendingAnalysisSummaryResponse {
  DocumentMetadata?: DocumentMetadata | undefined;
  JobStatus?: JobStatus | undefined;
  Summary?: LendingSummary | undefined;
  Warnings?: Warning[] | undefined;
  StatusMessage?: string | undefined;
  AnalyzeLendingModelVersion?: string | undefined;
}
export interface ListAdaptersRequest {
  AfterCreationTime?: Date | undefined;
  BeforeCreationTime?: Date | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAdaptersResponse {
  Adapters?: AdapterOverview[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAdapterVersionsRequest {
  AdapterId?: string | undefined;
  AfterCreationTime?: Date | undefined;
  BeforeCreationTime?: Date | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAdapterVersionsResponse {
  AdapterVersions?: AdapterVersionOverview[] | undefined;
  NextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  ResourceARN: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Record<string, string> | undefined;
}
export interface NotificationChannel {
  SNSTopicArn: string | undefined;
  RoleArn: string | undefined;
}
export interface StartDocumentAnalysisRequest {
  DocumentLocation: DocumentLocation | undefined;
  FeatureTypes: FeatureType[] | undefined;
  ClientRequestToken?: string | undefined;
  JobTag?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  OutputConfig?: OutputConfig | undefined;
  KMSKeyId?: string | undefined;
  QueriesConfig?: QueriesConfig | undefined;
  AdaptersConfig?: AdaptersConfig | undefined;
}
export interface StartDocumentAnalysisResponse {
  JobId?: string | undefined;
}
export interface StartDocumentTextDetectionRequest {
  DocumentLocation: DocumentLocation | undefined;
  ClientRequestToken?: string | undefined;
  JobTag?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  OutputConfig?: OutputConfig | undefined;
  KMSKeyId?: string | undefined;
}
export interface StartDocumentTextDetectionResponse {
  JobId?: string | undefined;
}
export interface StartExpenseAnalysisRequest {
  DocumentLocation: DocumentLocation | undefined;
  ClientRequestToken?: string | undefined;
  JobTag?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  OutputConfig?: OutputConfig | undefined;
  KMSKeyId?: string | undefined;
}
export interface StartExpenseAnalysisResponse {
  JobId?: string | undefined;
}
export interface StartLendingAnalysisRequest {
  DocumentLocation: DocumentLocation | undefined;
  ClientRequestToken?: string | undefined;
  JobTag?: string | undefined;
  NotificationChannel?: NotificationChannel | undefined;
  OutputConfig?: OutputConfig | undefined;
  KMSKeyId?: string | undefined;
}
export interface StartLendingAnalysisResponse {
  JobId?: string | undefined;
}
export interface TagResourceRequest {
  ResourceARN: string | undefined;
  Tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  ResourceARN: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateAdapterRequest {
  AdapterId: string | undefined;
  Description?: string | undefined;
  AdapterName?: string | undefined;
  AutoUpdate?: AutoUpdate | undefined;
}
export interface UpdateAdapterResponse {
  AdapterId?: string | undefined;
  AdapterName?: string | undefined;
  CreationTime?: Date | undefined;
  Description?: string | undefined;
  FeatureTypes?: FeatureType[] | undefined;
  AutoUpdate?: AutoUpdate | undefined;
}
